#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Configuration of the Linux specific tools to enhance the ease of use
of the CIRCLE cloud. Handles the auto launch and auto configuration
of these specific connectivity programs.
"""

import time
import os
import subprocess
import glob
import remminapasswd


def connect(vm):
    """
    Handles to connection to the Virtual Machines from the local
    machine

    Keyword arguments:
    vm.protocol -- SSH, NX and RDP possible
    vm.host     -- Address of the Virtual Computer
    vm.port     -- The port where we can access the Virtual Computer
    vm.user     -- Username used for the connection
    vm.password -- Password used for the connection
    """
    if vm.protocol == "SSH":
        command = ("sshpass -p %(password)s ssh -p %(port)s"
                   " -o StrictHostKeyChecking=no %(user)s@%(host)s" % {
                       'password': vm.password,
                       'port': vm.port,
                       'user': vm.user,
                       'host': vm.host
                   })
        subprocess.call(command, shell=True)
    elif vm.protocol in ("NX", "RDP"):
        server = "%s:%s" % (vm.host, vm.port)
        listdir = os.path.expanduser("~/.remmina/*.remmina")
        found = False
        for config_file in glob.glob(listdir):
            with open(config_file) as f:
                if server in f.read():
                    found = True
                    break
        if not found:
            config_file = "%s%s%s" % (
                os.path.expanduser("~/.remmina/"),
                str(int(time.time()*1000)), ".remmina")
            password = remminapasswd.remminapasswd(vm.password)
            f = open(config_file, 'w')
            if vm.protocol == "NX":
                f.write(NX_template)
            else:
                f.write(RDP_template)
            f.write("name=%(protocol)s:%(server)s\nprotocol=%(protocol)s\n"
                    "server=%(server)s\nusername=%(username)s\n"
                    "password=%(password)s\n" % {
                        'protocol': vm.protocol,
                        'server': server,
                        'username': vm.user,
                        'password': password
                    })
            f.close()
        subprocess.call(["remmina", "-c", config_file])


NX_template = """[remmina]
ssh_auth=0
quality=2
disableencryption=0
ssh_loopback=0
ssh_enabled=0
nx_privatekey=
showcursor=0
disableclipboard=0
window_maximize=1
viewmode=4
"""

RDP_template = """[remmina]
disableclipboard=0
ssh_auth=0
quality=2
console=0
ssh_loopback=0
shareprinter=0
sound=off
ssh_enabled=0
colordepth=24
window_maximize=1
viewmode=4
"""
