#!/usr/bin/env python

from distutils.core import setup, Extension
import subprocess
# patch distutils if it can't cope with the "classifiers" or
# "download_url" keywords
from sys import version
if version < '2.2.3':
    from distutils.dist import DistributionMetadata
    DistributionMetadata.classifiers = None
    DistributionMetadata.download_url = None

compile_args = ['-DHAVE_LIBGCRYPT']
linker_args = []


def decide_options(arguments, compile_arguments, linker_arguments):
    for argument in arguments:
        if argument[:2] == '-l':
            linker_arguments.append(argument)
        else:
            compile_arguments.append(argument)


def list_output(cmd):
    p = subprocess.Popen(
        cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
        stdin=subprocess.PIPE)
    return p.communicate()[0].split()

cmd = ['pkg-config', '--libs', '--cflags', 'gtk+-2.0', 'glib-2.0']
decide_options(list_output(cmd), compile_args, linker_args)

cmd = ['libgcrypt-config', '--libs', '--cflags']
decide_options(list_output(cmd), compile_args, linker_args)

remminapasswd = Extension('remminapasswd',
                          sources=['remminapasswdmodule.c',
                                   'remmina_crypt.c',
                                   'remmina_pref.c',
                                   'remmina_string_array.c'],
                          extra_compile_args=compile_args,
                          extra_link_args=linker_args)

setup(name='CIRCLE Client',
      version='0.1',
      license='GPLv3',
      platforms=[
          'linux2',
          'posix'],
      description='Connectivity helper for CIRCLE cloud system',
      long_description=(
          'Tool to enhance ease of use of the CIRCLE by '
          'the use of third party connetcion handler programs. '
          'These programs are auto launched and '
          'configured by the Client.'),
      author='Csok Tamas',
      author_email='csok.tamas@cloud.bme.hu',
      maintainer='BME IK',
      maintainer_email='cloud@ik.bme.hu',
      url='http://circlecloud.org/',
      scripts=['cloud.py', 'cloud2', 'cloud_connect_from_linux.py'],
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Web Environment',
          'Environment :: X11 Applications',
          'Operating System :: POSIX :: Linux',
          'Operating System :: Unix',
          'Intended Audience :: End Users/Desktop',
          'Intended Audience :: System Administrators',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: C',
          'Programming Language :: Unix Shell',
          ('License :: OSI Approved :: GNU General Public'
           'License v3 or later (GPLv3+)'),
          'Natural Language :: English',
          'Topic :: Office/Business',
          'Topic :: System :: Networking'],
      ext_modules=[remminapasswd])
